@@ -7,6 +7,7 @@ fbolus1 <- function(InVVRefindex,
                     MMe=FALSE)
 {
    #options(warn=-1)
+   modfun<-NULL
    ## Input dose and initial value for kel and Vd
    if (is.null(Dose)) {
    cat("Enter Dose value\n")
@@ -31,9 +32,8 @@ fbolus1 <- function(InVVRefindex,
       list(dCpdt) 
       } 
     
-      modfun <- function(time,kel, Vd) {  
-      out <- lsoda(Dose/Vd,c(0,time),defun,parms=c(kel=kel,Vd=Vd),
-                   rtol=1e-3,atol=1e-5) 
+      modfun <<- function(time,kel, Vd) {  
+      out <- lsoda(Dose/Vd,c(0,time),defun,parms=c(kel=kel,Vd=Vd),rtol=1e-08,atol=1e-08) 
       out[-1,2] 
       }
 
@@ -61,17 +61,6 @@ fbolus1 <- function(InVVRefindex,
              sum((InVVRefindex$conc[InVVRefindex$subj==i][gift]-out[gift])^2/InVVRefindex$conc[gift]),
              sum(((InVVRefindex$conc[InVVRefindex$subj==i][gift]-out[gift])/InVVRefindex$conc[gift])^2))
         }
-### #The value of parameter obtained from genetic algorithm   
-###           gen<-genoud(objfun,nvars=2,max=FALSE,pop.size=30,
-###                max.generations=20,wait.generations=10,
-###                starting.values=c(par[1,2],par[2,2]),
-###                BFGS=FALSE,print.level=0,boundary.enforcement=2,
-###                Domains=matrix(c(0.01,0.01,100,100),2,2),
-###                MemoryMatrix=TRUE)  
-### ## No MM elimination
-###           namegen<-c("kel","Vd")
-###           outgen<-c(gen$par[1],gen$par[2])
-###           F<-objfun(gen$par)
 
 ##fitted by Nelder-Mead Simplex algorithm      
           opt<-optim(c(par[1,2],par[2,2]),objfun,method="Nelder-Mead")  
@@ -79,18 +68,31 @@ fbolus1 <- function(InVVRefindex,
           outopt<-c(opt$par[1],opt$par[2])
           ke[i]<- opt$par[1]
           Vd[i]<- opt$par[2]
+          
+          if(opt$par[1]<0) opt$par[1]<-0.001
+          if(opt$par[2]<0) opt$par[2]<-0.001
+          
+          conc<-InVVRefindex$conc[InVVRefindex$subj==i]
+          time<-InVVRefindex$time[InVVRefindex$subj==i]
+          
+          if(pick==1) weights=(1/conc^0)  ### equal weight
+          if(pick==2) weights=(1/conc^1)  ### 1/Cp
+          if(pick==3) weights=(1/conc^2)  ### 1/Cp^2
 
        cat("\n<< The value of parameter fitted by Nelder-Mead Simplex algorithm >>\n\n")
        print(data.frame(Parameter=nameopt,Value=outopt))
        
        ##Residuals sum-of-squares and parameter values fitted by nls
-       cat("\n<< Residual sum-of-squares and parameter values fitted by nls >>\n\n")
+       cat("\n<< Residual sum-of-squares and parameter values fitted by nlsLM >>\n\n")
        ## No MM elimination
-       fm<-nls(conc ~ modfun(time, kel, Vd), data=InVVRefindex,
-               start=list(kel=opt$par[1],Vd=opt$par[2]),trace=TRUE,subset=subj==i,
-               nls.control(tol=1))
+
+       fm<-nlsLM(conc ~ modfun(time, ke, Vd), data=subset(InVVRefindex,subj==i),
+                 start=list(ke=opt$par[1],Vd=opt$par[2]),weights=weights,
+                 control=nls.lm.control(maxiter=500),lower=c(1e-06,1e-06))
        cat("\n")
-       coef<-data.frame(coef(fm)["kel"])
+       ke[i]<-data.frame(coef(fm)["ke"])[1,1]  ### extract ke value from fm
+       Vd[i]<-data.frame(coef(fm)["Vd"])[1,1]  ### extract Vd value from fm
+       coef <-data.frame(coef(fm)["ke"])
        plotting.lin(InVVRefindex, fm, i, pick, coef, xaxis, yaxis)
    }
        cat("<< Summary >>\n")
